@@ -76,7 +76,7 @@ class BinanceAIP(AIPBase):
         try:
             lending_product = self.__handler.daily_lending_product(coin)
             if lending_product is None:
-                print('找不到 {coin} 活期产品')
+                print(F'找不到 {coin} 活期产品')
             else:
                 product_id = lending_product['productId']
                 print(lending_product)
@@ -84,6 +84,6 @@ class BinanceAIP(AIPBase):
                 if amount > 0:
                     result = self.__handler.purchase_daily_lending_product(product_id, amount).get('purchaseId')
                     if result is None:
-                        print('购买 {coin} 活期失败')
+                        print(F'购买 {coin} 活期失败')
         except Exception as e:
             print(F'**划转 {coin} 到活期失败，{str(e)}**')
